@@ -1,6 +1,7 @@
 /*
  * Java ATK Wrapper for GNOME
  * Copyright (C) 2009 Sun Microsystems Inc.
+ * Copyright (C) 2015 Magdalen Berns <m.berns@thismagpie.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -260,7 +261,7 @@ jaw_component_set_extents (AtkComponent *component,
   jmethodID jmid = (*jniEnv)->GetMethodID(jniEnv,
                                           classAtkComponent,
                                           "set_extents",
-                                          "(IIII)Ljava/awt/Rectangle;");
+                                          "(IIIII)Ljava/awt/Rectangle;");
 
   jobject jcomponent = (*jniEnv)->CallObjectMethod(jniEnv,
                                                    atk_component,
